@@ -10,7 +10,7 @@ running ::
   docker info
 
 Please report any feedback to our GitHub repository
-(https://github.com/poldracklab/fmriprep) and do not
+(https://github.com/nipreps/fmriprep) and do not
 forget to credit all the authors of software that fMRIPrep
 uses (https://fmriprep.readthedocs.io/en/latest/citing.html).
 """
@@ -19,11 +19,11 @@ import os
 import re
 import subprocess
 
-__version__ = '20.1.3'
+__version__ = '20.2.2'
 __copyright__ = 'Copyright 2020, Center for Reproducible Neuroscience, Stanford University'
 __credits__ = ['Craig Moodie', 'Ross Blair', 'Oscar Esteban', 'Chris Gorgolewski',
                'Shoshana Berleant', 'Christopher J. Markiewicz', 'Russell A. Poldrack']
-__bugreports__ = 'https://github.com/poldracklab/fmriprep/issues'
+__bugreports__ = 'https://github.com/nipreps/fmriprep/issues'
 
 
 MISSING = """
@@ -166,8 +166,10 @@ def merge_help(wrapper_help, target_help):
     overlap = set(w_flags).intersection(t_flags)
     expected_overlap = {
         'anat-derivatives',
+        'bids-database-dir',
         'fs-license-file',
         'fs-subjects-dir',
+        'config-file',
         'h',
         'use-plugin',
         'version',
@@ -266,7 +268,7 @@ def get_parser():
 
     # Allow alternative images (semi-developer)
     parser.add_argument('-i', '--image', metavar='IMG', type=str,
-                        default='poldracklab/fmriprep:{}'.format(__version__),
+                        default='nipreps/fmriprep:{}'.format(__version__),
                         help='image name')
 
     # Options for mapping files and directories into container
@@ -299,6 +301,10 @@ the spatial normalization.""" % (', '.join('"%s"' % s for s in TF_TEMPLATES),
         '--fs-subjects-dir', metavar='PATH', type=os.path.abspath,
         help='Path to existing FreeSurfer subjects directory to reuse. '
              '(default: OUTPUT_DIR/freesurfer)')
+    g_wrap.add_argument(
+        '--config-file', metavar='PATH', type=os.path.abspath,
+        help="Use pre-generated configuration file. Values in file will be overridden "
+             "by command-line arguments.")
     g_wrap.add_argument(
         '--anat-derivatives', metavar='PATH', type=os.path.abspath,
         help='Path to existing sMRIPrep/fMRIPrep-anatomical derivatives to fasttrack '
@@ -306,6 +312,10 @@ the spatial normalization.""" % (', '.join('"%s"' % s for s in TF_TEMPLATES),
     g_wrap.add_argument(
         '--use-plugin', metavar='PATH', action='store', default=None,
         type=os.path.abspath, help='nipype plugin configuration file')
+    g_wrap.add_argument(
+        '--bids-database-dir', metavar='PATH', type=os.path.abspath,
+        help="Path to an existing PyBIDS database folder, for faster indexing "
+             "(especially useful for large datasets).")
 
     # Developer patch/shell options
     g_dev = parser.add_argument_group(
@@ -325,6 +335,8 @@ the spatial normalization.""" % (', '.join('"%s"' % s for s in TF_TEMPLATES),
     g_dev.add_argument('--network', action='store',
                        help='Run container with a different network driver '
                             '("none" to simulate no internet connection)')
+    g_dev.add_argument('--no-tty', action='store_true',
+                       help='Run docker without TTY flag -it')
 
     return parser
 
@@ -393,9 +405,12 @@ def main():
                          stdout=subprocess.PIPE)
     docker_version = ret.stdout.decode('ascii').strip()
 
-    command = ['docker', 'run', '--rm', '-it', '-e',
+    command = ['docker', 'run', '--rm', '-e',
                'DOCKER_VERSION_8395080871=%s' % docker_version]
 
+    if not opts.no_tty:
+        command.append('-it')
+
     # Patch working repositories into installed package directories
     if opts.patch:
         for pkg, repo_path in opts.patch.items():
@@ -431,6 +446,10 @@ def main():
         command.extend(['-v', '{}:/opt/subjects'.format(opts.fs_subjects_dir)])
         unknown_args.extend(['--fs-subjects-dir', '/opt/subjects'])
 
+    if opts.config_file:
+        command.extend(['-v', '{}:/tmp/config.toml'.format(opts.config_file)])
+        unknown_args.extend(['--config-file', '/tmp/config.toml'])
+
     if opts.anat_derivatives:
         command.extend(['-v', '{}:/opt/smriprep/subjects'.format(opts.anat_derivatives)])
         unknown_args.extend(['--anat-derivatives', '/opt/smriprep/subjects'])
@@ -456,6 +475,10 @@ def main():
                                         'ro'))])
         unknown_args.extend(['--use-plugin', '/tmp/plugin.yml'])
 
+    if opts.bids_database_dir:
+        command.extend(['-v', ':'.join((opts.bids_database_dir, '/tmp/bids_db'))])
+        unknown_args.extend(['--bids-database-dir', '/tmp/bids_db'])
+
     if opts.output_spaces:
         spaces = []
         for space in opts.output_spaces:
